aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/graph/nodes/EltwiseLayerNode.h
diff options
context:
space:
mode:
authorSang-Hoon Park <sang-hoon.park@arm.com>2020-03-06 16:32:01 +0000
committerGeorgios Pinitas <georgios.pinitas@arm.com>2020-03-11 18:34:03 +0000
commit6800117df3be825f0ec5c6cc71c4377322f51b99 (patch)
tree0e579a271f2676dc2d6aa947df29a5cf0ab8bd1c /arm_compute/graph/nodes/EltwiseLayerNode.h
parent9204646e091ffc25eda61768537357916a4f7df4 (diff)
downloadComputeLibrary-6800117df3be825f0ec5c6cc71c4377322f51b99.tar.gz
COMPMID-3221: (DATA_UPDATE) add graph example for EDSR
Change-Id: Id74190e2af444da8dab4813fd65016104f3882a9 Signed-off-by: Sang-Hoon Park <sang-hoon.park@arm.com> Reviewed-on: https://review.mlplatform.org/c/ml/ComputeLibrary/+/2862 Tested-by: Arm Jenkins <bsgcomp@arm.com> Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com> Comments-Addressed: Arm Jenkins <bsgcomp@arm.com>
Diffstat (limited to 'arm_compute/graph/nodes/EltwiseLayerNode.h')
-rw-r--r--arm_compute/graph/nodes/EltwiseLayerNode.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/arm_compute/graph/nodes/EltwiseLayerNode.h b/arm_compute/graph/nodes/EltwiseLayerNode.h
index 7fb0aff640..1ca8e9c23d 100644
--- a/arm_compute/graph/nodes/EltwiseLayerNode.h
+++ b/arm_compute/graph/nodes/EltwiseLayerNode.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2018-2019 ARM Limited.
+ * Copyright (c) 2018-2020 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -36,11 +36,12 @@ class EltwiseLayerNode final : public INode
public:
/** Constructor
*
* @param[in] op Element-wise operation to perform
* @param[in] c_policy (Optional) Convert policy used for the operation
* @param[in] r_policy (Optional) Rounding policy used for the operation
*/
- EltwiseLayerNode(EltwiseOperation op, ConvertPolicy c_policy = ConvertPolicy::SATURATE, RoundingPolicy r_policy = RoundingPolicy::TO_ZERO);
+ EltwiseLayerNode(EltwiseOperation op, QuantizationInfo out_quant_info = QuantizationInfo(), ConvertPolicy c_policy = ConvertPolicy::SATURATE, RoundingPolicy r_policy = RoundingPolicy::TO_ZERO);
/** Eltwise operation accessor
*
* @return Eltwise operation that is to be performed by the node
@@ -67,6 +68,7 @@ public:
private:
EltwiseOperation _op;
+ QuantizationInfo _out_quant_info;
ConvertPolicy _convert_policy;
RoundingPolicy _rounding_policy;
};
@@ -36,11 +36,12 @@ class EltwiseLayerNode final : public INode
/** Constructor
*
- * @param[in] op Element-wise operation to perform
- * @param[in] c_policy (Optional) Convert policy used for the operation
- * @param[in] r_policy (Optional) Rounding policy used for the operation
+ * @param[in] op Element-wise operation to perform
+ * @param[in] out_quant_info (Optional) Output quantization information
+ * @param[in] c_policy (Optional) Convert policy used for the operation
+ * @param[in] r_policy (Optional) Rounding policy used for the operation
*/